.. mdfreader documentation master file, created by
   sphinx-quickstart on Wed Dec 10 23:56:46 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mdfreader's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 3

   mdfreader/index

   mdf/index

   mdf3reader/index

   mdfinfo3/index

   mdf4reader/index

   mdfinfo4/index

   channel/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

